@@ -48,6 +48,7 @@
 #import "SOGoSentFolder.h"
 #import "SOGoTrashFolder.h"
 #import "SOGoJunkFolder.h"
+#import "SOGoTemplatesFolder.h"
 #import "SOGoUser+Mailer.h"
 
 #import "SOGoMailAccount.h"
@@ -70,6 +71,7 @@ static NSString *inboxFolderName = @"INBOX";
       sentFolder = nil;
       trashFolder = nil;
       junkFolder = nil;
+      templatesFolder = nil;
       imapAclStyle = undefined;
       identities = nil;
       otherUsersFolderName = nil;
@@ -88,6 +90,7 @@ static NSString *inboxFolderName = @"INBOX";
   [sentFolder release];
   [trashFolder release];
   [junkFolder release];
+  [templatesFolder release];
   [identities release];
   [otherUsersFolderName release];
   [sharedFoldersName release];
@@ -100,6 +103,11 @@ static NSString *inboxFolderName = @"INBOX";
   return NO;
 }
 
+- (BOOL) isInTemplatesFolder
+{
+  return NO;
+}
+
 - (void) _appendNamespace: (NSArray *) namespace
                 toFolders: (NSMutableArray *) folders
 {
@@ -406,6 +414,7 @@ static NSString *inboxFolderName = @"INBOX";
 			  [self sentFolderNameInContext: context],
 			  [self trashFolderNameInContext: context],
 			  [self junkFolderNameInContext: context],
+			  [self templatesFolderNameInContext: context],
 		    nil] stringsWithFormat: @"/%@"];
   folders = [[self imap4Connection] allFoldersForURL: [self imap4URL]
 			       onlySubscribedFolders: subscribedOnly];
@@ -479,6 +488,9 @@ static NSString *inboxFolderName = @"INBOX";
   else if ([flags containsObject: [self junkFolderNameInContext: context]] ||
            [folderName isEqualToString: [self junkFolderNameInContext: context]])
     folderType = @"junk";
+  else if ([flags containsObject: [self templatesFolderNameInContext: context]] ||
+           [folderName isEqualToString: [self templatesFolderNameInContext: context]])
+    folderType = @"templates";
   else if ([folderName isEqualToString: otherUsersFolderName])
     folderType = @"otherUsers";
   else if ([folderName isEqualToString: sharedFoldersName])
@@ -1012,6 +1024,9 @@ static NSString *inboxFolderName = @"INBOX";
       else if ([folderName
 		 isEqualToString: [self junkFolderNameInContext: _ctx]])
 	klazz = [SOGoJunkFolder class];
+      else if ([folderName
+		 isEqualToString: [self templatesFolderNameInContext: _ctx]])
+	klazz = [SOGoTemplatesFolder class];
       else
 	klazz = [SOGoMailFolder class];
 
@@ -1081,6 +1096,11 @@ static NSString *inboxFolderName = @"INBOX";
   return [self _userFolderNameWithPurpose: @"Junk"];
 }
 
+- (NSString *) templatesFolderNameInContext: (id)_ctx
+{
+  return [self _userFolderNameWithPurpose: @"Templates"];
+}
+
 - (NSString *) otherUsersFolderNameInContext: (id)_ctx
 {
   return otherUsersFolderName;
@@ -1186,12 +1206,25 @@ static NSString *inboxFolderName = @"INBOX";
       junkFolder
 	= [self folderWithTraversal: [self junkFolderNameInContext: _ctx]
                        andClassName: @"SOGoJunkFolder"];
-      [trashFolder retain];
+      [junkFolder retain];
     }
 
   return junkFolder;
 }
 
+- (SOGoTemplatesFolder *) templatesFolderInContext: (id) _ctx
+{
+  if (!templatesFolder)
+    {
+      templatesFolder
+	= [self folderWithTraversal: [self templatesFolderNameInContext: _ctx]
+                       andClassName: @"SOGoTemplatesFolder"];
+      [templatesFolder retain];
+    }
+
+  return templatesFolder;
+}
+
 /* account delegation */
 - (NSArray *) delegates
 {
