@@ -265,12 +265,12 @@
               identity = [[sourceMail mailAccountFolder] identityForEmail: email];
             }
         }
-    }
 
-  if (!identity)
-    {
-      identity = [[context activeUser] defaultIdentity];
+      if (!identity)
+        identity = [[sourceMail mailAccountFolder] defaultIdentity];
     }
+  else
+    identity = [[context activeUser] defaultIdentity];
 
   if (identity)
     {
@@ -351,6 +351,9 @@
 @implementation SOGoMailJapaneseForward
 @end
 
+@implementation SOGoMailKazakhForward
+@end
+
 @implementation SOGoMailLatvianForward
 @end
 
