@@ -1,6 +1,6 @@
 /* SOGoMailNamespace.m - this file is part of SOGo
  *
- * Copyright (C) 2010-2013 Inverse inc.
+ * Copyright (C) 2010-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,9 @@
       else if ([fullFolderName isEqualToString:
                                  [mailAccount trashFolderNameInContext: _ctx]])
         className = @"SOGoTrashFolder";
+      else if ([fullFolderName isEqualToString:
+                                 [mailAccount junkFolderNameInContext: _ctx]])
+        className = @"SOGoJunkFolder";
       /*       else if ([folderName isEqualToString:
                [mailAccount sieveFolderNameInContext: _ctx]])
                obj = [self lookupFiltersFolder: _key inContext: _ctx]; */
