@@ -1,14 +1,15 @@
 /*
   Copyright (C) 2005 SKYRIX Software AG
+  Copyright (C) 2007-2016 Inverse inc.
 
-  This file is part of OpenGroupware.org.
+  This file is part of SOGo.
 
-  OGo is free software; you can redistribute it and/or modify it under
+  SOGo is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.
 
-  OGo is distributed in the hope that it will be useful, but WITHOUT ANY
+  SOGo is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
   License for more details.
@@ -19,8 +20,6 @@
   02111-1307, USA.
 */
 
-#import <Foundation/NSString.h>
-
 #import "SOGoTrashFolder.h"
 
 @implementation SOGoTrashFolder
