@@ -413,7 +413,7 @@
   davPrivileges = [NSMutableArray array];
 
   privileges = [[webdavAclManager davPermissionsForRoles: roles
-				  onObject: self] objectEnumerator];
+                                                onObject: self] objectEnumerator];
   while ((privilege = [privileges nextObject]))
     [davPrivileges addObject: davElementWithContent (@"privilege", XMLNS_WEBDAV,
 						     privilege)];
@@ -601,7 +601,7 @@
   id etag;
 
   response = [localContext response];
-  contentType = [NSString stringWithFormat: @"%@; charset=utf8",
+  contentType = [NSString stringWithFormat: @"%@; charset=utf-8",
 			  [self davContentType]];
   [response setHeader: contentType forKey: @"content-type"];
   [response appendContentString: [self contentAsString]];
