@@ -1,8 +1,6 @@
 /* SOGoSieveManager.m - this file is part of SOGo
  *
- * Copyright (C) 2010-2019 Inverse inc.
- *
- * Author: Inverse <info@inverse.ca>
+ * Copyright (C) 2010-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,6 +52,7 @@ typedef enum {
 static NSArray *sieveOperators = nil;
 static NSArray *sieveSizeOperators = nil;
 static NSMutableDictionary *fieldTypes = nil;
+static NSMutableDictionary *imapDelimiters = nil;
 static NSDictionary *sieveFields = nil;
 static NSDictionary *sieveFlags = nil;
 static NSDictionary *typeRequirements = nil;
@@ -129,7 +128,7 @@ static NSString *sieveScriptName = @"sogo";
   if (!sieveOperators)
     {
       sieveOperators = [NSArray arrayWithObjects: @"is", @"contains",
-                                @"matches", @"regex",
+                                @"matches", @"regex", @"regex :comparator \"i;octet\"",
                                 @"over", @"under", nil];
       [sieveOperators retain];
     }
@@ -153,6 +152,10 @@ static NSString *sieveScriptName = @"sogo";
       [fieldTypes setObject: [NSNumber numberWithInt: UIxFilterFieldTypeSize]
                      forKey: @"size"];
     }
+  if (!imapDelimiters)
+    {
+      imapDelimiters = [NSMutableDictionary new];
+    }
   if (!sieveFields)
     {
       sieveFields
@@ -364,6 +367,8 @@ static NSString *sieveScriptName = @"sogo";
           requirement = [operatorRequirements objectForKey: baseOperator];
           if (requirement)
             [requirements addObjectUniquely: requirement];
+          if ([baseOperator isEqualToString: @"regex"])
+            baseOperator = @"regex :comparator \"i;octet\""; // case-sensitive comparator
           *operator = baseOperator;
         }
       else
@@ -844,7 +849,7 @@ static NSString *sieveScriptName = @"sogo";
                      andPassword: (NSString *) thePassword
                  forceActivation: (BOOL) forceActivation
 {
-  NSString *filterScript, *v, *delimiter, *content, *message;
+  NSString *filterScript, *v, *delimiter, *imapHost, *content, *message;
   NSMutableArray *req;
   NSMutableString *script, *header;
   NSDictionary *result, *values;
@@ -893,24 +898,34 @@ static NSString *sieveScriptName = @"sogo";
   //
   script = [NSMutableString string];
 
-  // We grab the IMAP4 delimiter using the supplied username/password
-  if (thePassword)
+
+  imapHost = [NSString stringWithFormat: @"%@:%i", [[theAccount imap4URL] host], [[[theAccount imap4URL] port] intValue]];
+  delimiter = [imapDelimiters objectForKey: imapHost];
+  if (!delimiter)
     {
-      imapClient = [NGImap4Client clientWithURL: [theAccount imap4URL]];
-      [imapClient login: theUsername  password: thePassword];
+      // We grab the IMAP4 delimiter using the supplied username/password
+      if (thePassword)
+        {
+          imapClient = [NGImap4Client clientWithURL: [theAccount imap4URL]];
+          [imapClient authenticate: [user login] authname: theUsername password: thePassword];
+        }
+      else
+        imapClient = [[theAccount imap4Connection] client];
+
+      delimiter = [imapClient delimiter];
+
+      if (!delimiter && [imapClient isConnected])
+        {
+          [imapClient list: @"INBOX"  pattern: @""];
+          delimiter = [imapClient delimiter];
+        }
+
+      if (!delimiter)
+        delimiter = [dd stringForKey: @"NGImap4ConnectionStringSeparator"];
+
+      // Cache result -- will benefit "sogo-tool update-autoreply"
+      [imapDelimiters setObject: delimiter forKey: imapHost];
     }
-  else
-    imapClient = [[theAccount imap4Connection] client];
-
-  delimiter = [imapClient delimiter];
-
-  if (!delimiter)
-    [imapClient list: @"INBOX"  pattern: @""];
-
-  delimiter = [imapClient delimiter];
-
-  if (!delimiter)
-    delimiter = [dd stringForKey: @"NGImap4ConnectionStringSeparator"];
 
   // We first handle filters
   filterScript = [self sieveScriptWithRequirements: req
@@ -1158,9 +1173,12 @@ static NSString *sieveScriptName = @"sogo";
 
   if (values && [[values objectForKey: @"enabled"] boolValue])
     {
+      BOOL alwaysSend;
+      NSString *redirect;
       id addresses;
       int i;
 
+      alwaysSend = [[values objectForKey: @"alwaysSend"] boolValue];
       b = YES;
 
       addresses = [values objectForKey: @"forwardAddress"];
@@ -1171,11 +1189,22 @@ static NSString *sieveScriptName = @"sogo";
         {
           v = [addresses objectAtIndex: i];
           if (v && [v length] > 0)
-            [script appendFormat: @"redirect \"%@\";\r\n", v];
+            {
+              redirect = [NSString stringWithFormat: @"redirect \"%@\";\r\n", v];
+              if (alwaysSend)
+                [script insertString: redirect  atIndex: 0];
+              else
+                [script appendString: redirect];
+            }
         }
 
       if ([[values objectForKey: @"keepCopy"] boolValue])
-        [script appendString: @"keep;\r\n"];
+        {
+          if (alwaysSend)
+            [script insertString: @"keep;\r\n"  atIndex: 0];
+          else
+            [script appendString: @"keep;\r\n"];
+        }
     }
 
   // We handle header/footer Sieve scripts
