@@ -1,6 +1,6 @@
 /* SOGoSystemDefaults.h - this file is part of SOGo
  *
- * Copyright (C) 2009-2016 Inverse inc.
+ * Copyright (C) 2009-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,8 @@
 
 - (BOOL) enableEMailAlarms;
 
+- (BOOL) disableOrganizerEventCheck;
+
 - (NSString *) faviconRelativeURL;
 - (NSString *) zipPath;
 - (int) port;
@@ -65,6 +67,7 @@
 
 - (BOOL) uixDebugEnabled;
 - (BOOL) easDebugEnabled;
+- (BOOL) tnefDecoderDebugEnabled;
 - (BOOL) xsrfValidationEnabled;
 
 - (NSString *) pageTitle;
@@ -112,6 +115,11 @@
 - (int) maximumSyncWindowSize;
 - (int) maximumSyncResponseSize;
 - (int) maximumPictureSize;
+- (BOOL) easSearchInBody;
+
+- (BOOL) isPasswordRecoveryEnabled;
+- (NSArray *) passwordRecoveryDomains;
+- (NSString *) JWTSecret;
 
 @end
 
