@@ -384,6 +384,12 @@ _injectConfigurationFromFile (NSMutableDictionary *defaultsDict,
   return [self boolForKey: @"SOGoEnableEMailAlarms"];
 }
 
+- (BOOL) disableOrganizerEventCheck
+{
+  return [self boolForKey: @"SOGoDisableOrganizerEventCheck"];
+}
+
+
 - (NSString *) faviconRelativeURL
 {
   return [self stringForKey: @"SOGoFaviconRelativeURL"];
@@ -755,4 +761,35 @@ _injectConfigurationFromFile (NSMutableDictionary *defaultsDict,
   return v;
 }
 
+- (BOOL) isPasswordRecoveryEnabled
+{
+  return [self boolForKey: @"SOGoPasswordRecoveryEnabled"];
+}
+
+- (NSArray *) passwordRecoveryDomains
+{
+  static NSArray *passwordRecoveryDomains = nil;
+
+  if (!passwordRecoveryDomains)
+    {
+      passwordRecoveryDomains = [self stringArrayForKey: @"SOGoPasswordRecoveryDomains"];
+      [passwordRecoveryDomains retain];
+    }
+
+  return passwordRecoveryDomains;
+}
+
+- (NSString *) JWTSecret
+{
+  NSString *secret;
+
+  secret = [self stringForKey: @"SOGoJWTSecret"];
+
+  if (!secret)
+    secret = @"SOGo"; // Default secret
+
+  return secret;
+}
+
+
 @end
