@@ -446,7 +446,7 @@ _xmlCharsetForCharset (NSString *charset)
            attributes: (id <SaxAttributes>) _attributes
 {
   unsigned int count, max;
-  NSString *name, *value, *cid, *lowerName;
+  NSString *name, *value, *cid, *lowerName, *lowerValue;
   NSMutableString *resultPart;
   BOOL skipAttribute;
 
@@ -518,11 +518,14 @@ _xmlCharsetForCharset (NSString *charset)
                        || [name isEqualToString: @"action"]
                        || [name isEqualToString: @"formaction"])
                 {
-                  value = [[_attributes valueAtIndex: count] lowercaseString];
-                  skipAttribute = ([value rangeOfString: @"://"].location == NSNotFound
-                                   && ![value hasPrefix: @"mailto:"]
-                                   && ![value hasPrefix: @"#"]) ||
-                    [value hasPrefix: @"javascript:"];
+                  value = [_attributes valueAtIndex: count];
+                  lowerValue = [[value lowercaseString] stringByReplacingString: @"\""
+                                                                     withString: @""];
+                  skipAttribute =
+                    ([lowerValue rangeOfString: @"://"].location == NSNotFound
+                     && ![lowerValue hasPrefix: @"mailto:"]
+                     && ![lowerValue hasPrefix: @"#"])
+                    || [lowerValue rangeOfString: @"javascript:"].location != NSNotFound;
                   if (!skipAttribute)
                     [resultPart appendString: @" rel=\"noopener\""];
                 }
@@ -530,9 +533,15 @@ _xmlCharsetForCharset (NSString *charset)
               else if ([name isEqualToString: @"style"])
                 {
                   value = [_attributes valueAtIndex: count];
-                  if ([value rangeOfString: @"url" options: NSCaseInsensitiveSearch].location != NSNotFound)
+                  lowerValue = [[value lowercaseString] stringByReplacingString: @"\""
+                                                                     withString: @""];
+                  if ([lowerValue rangeOfString: @"url"].location != NSNotFound)
                     name = [NSString stringWithFormat: @"unsafe-%@", name];
                 }
+	      else if ([name isEqualToString: @"rel"])
+		{
+		  skipAttribute = YES;
+		}
 	      else if ([name hasPrefix: @"on"])
 		{
                   // on Events
