@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2007-2014 Inverse inc.
+  Copyright (C) 2007-2022 Inverse inc.
 
   This file is part of SOGo.
 
@@ -33,7 +33,6 @@
 #import <Contacts/SOGoContactFolders.h>
 #import <Contacts/SOGoContactLDIFEntry.h>
 
-#import <Mailer/SOGoDraftsFolder.h>
 #import <Mailer/SOGoMailAccount.h>
 #import <Mailer/SOGoMailAccounts.h>
 #import <Mailer/SOGoMailLabel.h>
@@ -75,6 +74,11 @@
   [super dealloc];
 }
 
+- (NSString *) moduleName
+{
+  return [self commonLabelForKey: @"Mail"];
+}
+
 - (NSString *) modulePath
 {
   return @"Mail";
@@ -448,189 +452,6 @@
   return [super defaultAction];
 }
 
-- (BOOL) showToAddress 
-{
-  SOGoMailFolder *co;
-
-  if (!folderType)
-    {
-      co = [self clientObject];
-      if ([co isKindOfClass: [SOGoSentFolder class]]
-	  || [co isKindOfClass: [SOGoDraftsFolder class]])
-	folderType = 1;
-      else
-	folderType = -1;
-    }
-
-  return (folderType == 1);
-}
-
-- (NSDictionary *) columnsMetaData
-{
-  NSMutableDictionary *columnsMetaData;
-  NSArray *tmpColumns, *tmpKeys;
-
-  columnsMetaData = [NSMutableDictionary dictionaryWithCapacity: 8];
-  
-  tmpKeys = [NSArray arrayWithObjects: @"headerClass", @"headerId", @"value",
-                     nil];
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageThreadColumn tbtv_headercell",
-               @"invisibleHeader", @"Thread", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-                                                          forKeys: tmpKeys]
-                      forKey: @"Thread"];
-
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageSubjectColumn tbtv_headercell sortableTableHeader resizable",
-               @"subjectHeader", @"Subject", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-                                                          forKeys: tmpKeys]
-                      forKey: @"Subject"];
-  
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageFlagColumn tbtv_headercell",
-	       @"invisibleHeader", @"Flagged", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-					    forKeys: tmpKeys]
-		      forKey: @"Flagged"];
-
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageFlagColumn tbtv_headercell",
-	       @"attachmentHeader", @"Attachment", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-							  forKeys: tmpKeys]
-		      forKey: @"Attachment"];
-
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageFlagColumn tbtv_headercell", @"messageFlagHeader",
-	       @"Unread", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns forKeys: tmpKeys]
-		      forKey: @"Unread"];
-
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageAddressHeader tbtv_headercell sortableTableHeader resizable",
-	       @"toHeader", @"To", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns forKeys: tmpKeys]
-		      forKey: @"To"];
-  
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageAddressColumn tbtv_headercell sortableTableHeader resizable",
-	       @"fromHeader", @"From", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-							  forKeys: tmpKeys]
-		      forKey: @"From"];
-  
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageDateColumn tbtv_headercell sortableTableHeader resizable",
-	       @"dateHeader", @"Date", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-							  forKeys: tmpKeys]
-		      forKey: @"Date"];
-  
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messagePriorityColumn tbtv_headercell resizable", @"priorityHeader",
-	       @"Priority", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-							  forKeys: tmpKeys]
-		      forKey: @"Priority"];
-
-  tmpColumns
-    = [NSArray arrayWithObjects: @"messageSizeColumn tbtv_headercell sortableTableHeader", @"sizeHeader",
-	       @"Size", nil];
-  [columnsMetaData setObject: [NSDictionary dictionaryWithObjects: tmpColumns
-							  forKeys: tmpKeys]
-		      forKey: @"Size"];
-  
-  return columnsMetaData;
-}
-
-- (NSArray *) columnsDisplayOrder
-{
-  NSMutableArray *finalOrder, *invalid;
-  NSArray *available;
-  NSDictionary *metaData;
-  SOGoUserDefaults *ud;
-  NSUInteger i;
-
-  if (!columnsOrder)
-    {
-      ud = [[context activeUser] userDefaults];
-      columnsOrder = [ud mailListViewColumnsOrder];
-
-      metaData = [self columnsMetaData];
-
-      invalid = [columnsOrder mutableCopy];
-      [invalid autorelease];
-      available = [metaData allKeys];
-      [invalid removeObjectsInArray: available];
-      if ([invalid count] > 0)
-        {
-          [self errorWithFormat: @"those column names specified in"
-                @" SOGoMailListViewColumnsOrder are invalid: '%@'",
-                [invalid componentsJoinedByString: @"', '"]];
-          [self errorWithFormat: @"  falling back on hardcoded column order"];
-          columnsOrder = available;
-        }
-
-      finalOrder = [columnsOrder mutableCopy];
-      [finalOrder autorelease];
-
-      if (![ud mailSortByThreads])
-        [finalOrder removeObject: @"Thread"];
-      else
-        {
-          i = [finalOrder indexOfObject: @"Thread"];
-          if (i == NSNotFound)
-            [finalOrder insertObject: @"Thread" atIndex: 0];
-        }
-      if ([self showToAddress])
-        {
-          i = [finalOrder indexOfObject: @"From"];
-          if (i != NSNotFound)
-	    {
-	      [finalOrder removeObject: @"To"];
-	      [finalOrder replaceObjectAtIndex: i withObject: @"To"];
-	    }
-        }
-      else
-        {
-          i = [finalOrder indexOfObject: @"To"];
-          if (i != NSNotFound)
-	    {
-	      [finalOrder removeObject: @"From"];
-	      [finalOrder replaceObjectAtIndex: i withObject: @"From"];
-	    }
-	}
-
-      columnsOrder = [[self columnsMetaData] objectsForKeys: finalOrder
-                                             notFoundMarker: @""];
-      [columnsOrder retain];
-    }
-
-  return columnsOrder;
-}
-
-- (NSString *) columnsDisplayCount
-{
-  return [NSString stringWithFormat: @"%d", (int)[[self columnsDisplayOrder] count]];
-}
-
-- (void) setCurrentColumn: (NSDictionary *) newCurrentColumn
-{
-  ASSIGN (currentColumn, newCurrentColumn);
-}
-
-- (NSDictionary *) currentColumn
-{
-  return currentColumn;
-}
-
-- (NSString *) columnTitle
-{
-  return [self labelForKey: [currentColumn objectForKey: @"value"]];
-}
-
 - (unsigned int) _unseenCountForFolder: (NSString *) theFolder
 {
   NSArray *pathComponents;
