@@ -238,7 +238,10 @@
                                                  hours:[date hourOfDay]
                                                minutes:[date minuteOfHour]
                                                seconds:0];
-              [rule setUntilDate: untilDate];
+              if ([event isAllDay])
+                [rule setUntil: [untilDate descriptionWithCalendarFormat: @"%Y%m%d"]];
+              else
+                [rule setUntilDate: untilDate];
               [date release];
             }
         }
@@ -263,6 +266,24 @@
   return ex;
 }
 
+- (void) _removeAttendees: (NSArray *) emails
+{
+  NSString *email;
+  iCalEvent *event;
+  iCalPerson *attendee;
+  unsigned int i;
+
+  event = [self event];
+  attendee = [[[iCalPerson alloc] init] autorelease];
+
+  for (i = 0; i < [emails count]; i++)
+    {
+      email = [emails objectAtIndex: i];
+      [attendee setEmail: email];
+      [event removeFromAttendees: attendee];
+    }
+}
+
 /**
  * @api {post} /so/:username/Calendar/:calendarId/:appointmentId/rsvpAppointment Set participation state
  * @apiVersion 1.0.0
@@ -512,6 +533,7 @@
  */
 - (id <WOActionResults>) saveAction
 {
+  NSArray *removeAttendees;
   NSDictionary *params;
   NSString *jsonResponse;
   NSException *ex;
@@ -545,12 +567,19 @@
     {
       [self setAttributes: params];
       forceSave = [[params objectForKey: @"ignoreConflicts"] boolValue];
+      removeAttendees = [params objectForKey: @"removeAttendees"];
 
       if ([event hasRecurrenceRules])
         ex = [self _adjustRecurrentRules];
 
       if (!ex)
         {
+          if (removeAttendees)
+            {
+              [co expandGroupsInEvent: event];
+              [self _removeAttendees: removeAttendees];
+            }
+
           if ([co isNew])
             {
               if (componentCalendar
@@ -643,7 +672,8 @@
  * @apiSuccess (Success 200) {String} endDate                 End date (ISO8601)
  * @apiSuccess (Success 200) {String} localizedEndDate        Formatted end date
  * @apiSuccess (Success 200) {String} [localizedEndTime]      Formatted end time
- * @apiSuccess (Success 200) {Number} isReadOnly              1 if event is read-only
+ * @apiSuccess (Success 200) {Number} isEditable              1 if event can be edited by the active user
+ * @apiSuccess (Success 200) {Number} isErasable              1 if event can be deleted by the active user
  * @apiSuccess (Success 200) {Number} userHasRSVP             1 if owner is invited
  * @apiSuccess (Success 200) {Number} [reply]                 0 if needs-action, 1 if accepted, 2 if declined, 3 if tentative, 4 if delegated
  * @apiSuccess (Success 200) {Object[]} [attachUrls]          Attached URLs
@@ -797,7 +827,8 @@
                        [componentCalendar nameInContainer], @"pid",
                        [componentCalendar displayName], @"calendar",
                        [NSNumber numberWithBool: isAllDay], @"isAllDay",
-                       [NSNumber numberWithBool: [self isReadOnly]], @"isReadOnly",
+                       [NSNumber numberWithBool: [self isEditable]], @"isEditable",
+                       [NSNumber numberWithBool: [self isErasable]], @"isErasable",
                        [NSNumber numberWithBool: [self userHasRSVP]], @"userHasRSVP",
                        [eventStartDate iso8601DateString], @"startDate",
                        [eventEndDate iso8601DateString], @"endDate",
