@@ -8,7 +8,8 @@
    */
   AddressBookController.$inject = ['$scope', '$q', '$window', '$state', '$timeout', '$mdDialog', '$mdToast', 'Account', 'Card', 'AddressBook', 'sgFocus', 'Dialog', 'sgConstant', 'sgHotkeys', 'stateAddressbooks', 'stateAddressbook'];
   function AddressBookController($scope, $q, $window, $state, $timeout, $mdDialog, $mdToast, Account, Card, AddressBook, focus, Dialog, sgConstant, sgHotkeys, stateAddressbooks, stateAddressbook) {
-    var vm = this, hotkeys = [], sortLabels;
+    var vm = this, hotkeys = [], sortLabels,
+        defaultWindowTitle = angular.element($window.document).find('title').attr('sg-default') || "SOGo";
 
     sortLabels = {
       c_cn: 'Name',
@@ -36,8 +37,14 @@
           sgHotkeys.deregisterHotkey(key);
         });
       });
-    };
 
+      // Update window's title with name of selected addressbook
+      $scope.$watch(function() { return vm.selectedFolder.name; }, function(selectedAddressbookName) {
+        var title = selectedAddressbookName;
+        title += ' | ' + defaultWindowTitle;
+        $window.document.title = title;
+      });
+    };
 
     function _registerHotkeys(keys) {
       keys.push(sgHotkeys.createHotkey({
@@ -427,8 +434,9 @@
     };
 
     this.newListWithSelectedCards = function() {
+      var _this = this;
       var selectedCards = _.filter(this.selectedFolder.$cards, function(card) { return card.selected; });
-      var promises = [], refs = [];
+      var promises = [], ids = [], refs = [];
 
       _.forEach(selectedCards, function(card) {
         if (card.$isList({expandable: true})) {
@@ -451,8 +459,17 @@
         else if (card.$$email && card.$$email.length) {
           refs.push(card);
         }
+        else if (!card.$loaded) {
+          refs.push(card);
+          ids.push(card.id);
+        }
       });
 
+      if (ids.length) {
+        var futureHeadersData = AddressBook.$$resource.post(this.selectedFolder.id, 'headers', {ids: ids});
+        promises.push(_this.selectedFolder.$unwrapHeaders(futureHeadersData));
+      }
+
       $q.all(promises).then(function() {
         refs = _.uniqBy(_.map(refs, function(o) {
           return { reference: o.id || o.reference, email: o.$$email || o.email };
