@@ -4,7 +4,7 @@
 (function() {
   'use strict';
 
-  angular.module('SOGo.MailerUI', ['ngCookies', 'ui.router', 'ck', 'angularFileUpload', 'SOGo.Common', 'SOGo.ContactsUI', 'SOGo.SchedulerUI', 'ngAnimate', 'SOGo.PreferencesUI'])
+  angular.module('SOGo.MailerUI', ['ngCookies', 'ui.router', 'sgCkeditor', 'angularFileUpload', 'SOGo.Common', 'SOGo.ContactsUI', 'SOGo.SchedulerUI', 'ngAnimate', 'SOGo.PreferencesUI'])
     .config(configure)
     .run(runBlock);
 
@@ -109,6 +109,11 @@
             controllerAs: 'viewer'
           }
         },
+        params: {
+          reload: {
+            value: false
+          }
+        },
         onEnter: onEnterMessage,
         onExit: onExitMessage,
         resolve: {
@@ -144,7 +149,7 @@
 
     // Try to register SOGo has an handler for mailto: links
     if (navigator && navigator.registerProtocolHandler) {
-      var mailtoURL = window.location.origin + window.ApplicationBaseURL + 'UIxMailPopupView#!/Mail/0/INBOX/new?%s';
+      var mailtoURL = window.location.origin + window.ApplicationBaseURL + 'UIxMailPopupView#!/Mail/0/new?%s';
       try {
         navigator.registerProtocolHandler('mailto', mailtoURL, 'SOGo');
       }
@@ -255,11 +260,13 @@
     if (Mailbox.$virtualMode)
       return [];
 
-    if (stateMailbox)
+    if (stateMailbox) {
+      stateMailbox.$unselectMessages();
       promise = stateMailbox.$filter().catch(function() {
         // Mailbox not found
         return $q.reject('Mailbox not found');
       });
+    }
     else
       promise = $q.reject("Mailbox doesn't exist");
 
@@ -292,7 +299,7 @@
    */
   stateVirtualMailboxOfMessage.$inject = ['$q', 'Mailbox', 'decodeUriFilter', '$stateParams'];
   function stateVirtualMailboxOfMessage($q, Mailbox, decodeUriFilter, $stateParams) {
-    var mailboxId = decodeUriFilter($stateParams.mailboxId);
+    var mailboxId = decodeUriFilter(decodeUriFilter($stateParams.mailboxId));
 
     if (Mailbox.$virtualMode) {
       Mailbox.selectedFolder.resetSelectedMessage();
@@ -315,8 +322,8 @@
       return messageObject.uid == parseInt($stateParams.messageId);
     });
 
-    if (message) {
-      return message.$reload({useCache: true});
+    if (message && message.$reload) {
+      return message.$reload({useCache: !$stateParams.reload, nocache: $stateParams.reload});
     }
     else {
       // Message not found
@@ -329,7 +336,7 @@
    */
   onEnterMessage.$inject = ['$stateParams', 'stateMailbox'];
   function onEnterMessage($stateParams, stateMailbox) {
-    stateMailbox.selectedMessage = parseInt($stateParams.messageId);
+    stateMailbox.$selectedMessage = parseInt($stateParams.messageId);
   }
 
   /**
@@ -337,7 +344,7 @@
    */
   onExitMessage.$inject = ['stateMailbox'];
   function onExitMessage(stateMailbox) {
-    delete stateMailbox.selectedMessage;
+    delete stateMailbox.$selectedMessage;
   }
 
   /**
