@@ -132,6 +132,8 @@
         _this.flags.splice(i, 1,'_' + flag);
       }
     });
+    // isread will be undefined when composing a new message -- assume unseen flag is not set.
+    this.isread = angular.isDefined(this.isread) ? !!this.isread : true;
   };
 
   /**
@@ -273,8 +275,22 @@
    */
   Message.prototype.$shortAddress = function(type) {
     var address = '';
-    if (this[type] && this[type].length > 0) {
-      address = this[type][0].name || this[type][0].email || '';
+    if (this[type]) {
+      if (angular.isString(this[type])) {
+        // The recipient is a string; try to extract the name
+        var emailRE = /<?(([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?))/i;
+        var match = this[type].match(String.emailRE);
+        if (match) {
+          address = this[type].substring(0, match.index);
+          address = address.replace(/^\"? *(.+?)\"? *$/, "$1");
+        }
+        if (!address.length)
+          address = this[type];
+      }
+      else if (this[type].length > 0) {
+        // We have an array of objects; pick the first one
+        address = this[type][0].name || this[type][0].email || '';
+      }
     }
 
     return address;
@@ -540,6 +556,31 @@
       return Message.$$resource.post(this.$mailbox.$id(), 'addOrRemoveLabel', data);
   };
 
+  /**
+   * @function toggleRead
+   * @memberof Message.prototype
+   * @desc Toggle message unseen status
+   * @returns a promise of the HTTP operation
+   */
+  Message.prototype.toggleRead = function() {
+    var _this = this;
+
+    if (this.isread)
+      return Message.$$resource.fetch(this.$absolutePath(), 'markMessageUnread').then(function() {
+        Message.$timeout(function() {
+          _this.isread = false;
+          _this.$mailbox.unseenCount++;
+        });
+      });
+    else
+      return Message.$$resource.fetch(this.$absolutePath(), 'markMessageRead').then(function() {
+        Message.$timeout(function() {
+          _this.isread = true;
+          _this.$mailbox.unseenCount--;
+        });
+      });
+  };
+
   /**
    * @function $imipAction
    * @memberof Message.prototype
@@ -592,7 +633,7 @@
   Message.prototype.$deleteAttachment = function(filename) {
     var data = { 'filename': filename };
     var _this = this;
-    Message.$$resource.fetch(this.$absolutePath({asDraft: true}), 'deleteAttachment', data).then(function(data) {
+    return Message.$$resource.fetch(this.$absolutePath({asDraft: true}), 'deleteAttachment', data).then(function() {
       Message.$timeout(function() {
         _this.editable.attachmentAttrs = _.filter(_this.editable.attachmentAttrs, function(attachment) {
           return attachment.filename != filename;
@@ -635,7 +676,7 @@
       action = 'markMessageUncollapse';
 
     this.collapsed = !this.collapsed;
-    _this.$mailbox.updateVisibleMessages();
+    this.$mailbox.updateVisibleMessages();
 
     return Message.$$resource.post(this.$absolutePath(), action).catch(function() {
       this.collapsed = !this.collapsed;
@@ -664,13 +705,16 @@
     var _this = this, futureMessageData;
 
     if (options && options.useCache && this.$futureMessageData) {
+      // The message has already been fetched.
       if (!this.isread) {
-        Message.$$resource.fetch(this.$absolutePath(), 'markMessageRead').then(function() {
-          Message.$timeout(function() {
-            _this.isread = true;
-            _this.$mailbox.unseenCount--;
-          });
-        });
+        if (Message.$Preferences.defaults.SOGoMailAutoMarkAsReadDelay > -1)
+          // Automatically mark message as read
+          _this.$markAsReadPromise = Message.$timeout(function() {
+            Message.$$resource.fetch(_this.$absolutePath(), 'markMessageRead').then(function() {
+              _this.isread = true;
+              _this.$mailbox.unseenCount--;
+            });
+          }, Message.$Preferences.defaults.SOGoMailAutoMarkAsReadDelay * 1000);
       }
       return this;
     }
@@ -687,32 +731,33 @@
    * information parsed from the specified "mailto:" link.
    */
   Message.prototype.$parseMailto = function(mailto) {
-    var to, data, match = /^mailto:([^\?]+)/.exec(mailto);
+    var to, data = {}, match = /^mailto:([^\?]+)/.exec(mailto);
     if (match) {
       // Recipients
       to = _.map(decodeURIComponent(match[1]).split(','), function(email) {
         return '<' + email.trim() + '>';
       });
       data = { to: to };
-      // Subject & body
-      _.forEach(['subject', 'body'], function(param) {
-        var re = new RegExp(param + '=([^&]+)');
-        param = (param == 'body')? 'text' : param;
-        match = re.exec(mailto);
-        if (match)
-          data[param] = decodeURIComponent(match[1]);
-      });
-      // Other Recipients
-      _.forEach(['cc', 'bcc'], function(param) {
-        var re = new RegExp(param + '=([^&]+)');
-        match = re.exec(mailto);
-        if (match)
-          data[param] = _.map(decodeURIComponent(match[1]).split(','), function(email) {
-            return '<' + email.trim() + '>';
-          });
-      });
-      angular.extend(this.editable, data);
     }
+    // Subject & body
+    _.forEach(['subject', 'body'], function(param) {
+      var re = new RegExp(param + '=([^&]+)');
+      param = (param == 'body')? 'text' : param;
+      match = re.exec(mailto);
+      if (match)
+        data[param] = decodeURIComponent(match[1]);
+    });
+    // Other Recipients
+    _.forEach(['cc', 'bcc'], function(param) {
+      var re = new RegExp(param + '=([^&]+)');
+      match = re.exec(mailto);
+      if (match)
+        data[param] = _.map(decodeURIComponent(match[1]).split(','), function(email) {
+          return '<' + email.trim() + '>';
+        });
+    });
+    if (!_.isEmpty(data))
+      angular.extend(this.editable, data);
   };
 
   /**
@@ -745,10 +790,20 @@
     return this.$newDraft('forward');
   };
 
+  /**
+   * @function $compose
+   * @memberof Message.prototype
+   * @desc Prepare a new Message object as a new draft from a copy of this message.
+   * @returns a promise of the HTTP operations
+   */
+  Message.prototype.$compose = function() {
+    return this.$newDraft('compose');
+  };
+
   /**
    * @function $newDraft
    * @memberof Message.prototype
-   * @desc Prepare a new Message object as a reply or a forward of the current message and associated
+   * @desc Prepare a new Message object as a reply, a forward or a copy of the current message and associated
    * to the draft mailbox.
    * @see {@link Account.$newMessage}
    * @see {@link Message.$editableContent}
@@ -865,7 +920,18 @@
     // Resolve and expose the promise
     this.$futureMessageData = futureMessageData.then(function(data) {
       // Calling $timeout will force Angular to refresh the view
-      if (_this.isread === 0) {
+      if (!data.isRead) {
+        if (Message.$Preferences.defaults.SOGoMailAutoMarkAsReadDelay > -1)
+          // Automatically mark message as read
+          _this.$markAsReadPromise = Message.$timeout(function() {
+            Message.$$resource.fetch(_this.$absolutePath(), 'markMessageRead').then(function() {
+              _this.isread = true;
+              _this.$mailbox.unseenCount--;
+            });
+          }, Message.$Preferences.defaults.SOGoMailAutoMarkAsReadDelay * 1000);
+      }
+      else if (!_this.isread) {
+        // Message as already been marked read on the server
         _this.isread = true;
         _this.$mailbox.unseenCount--;
       }
