@@ -101,6 +101,8 @@
         // Cancel automatic mark as read
         if (vm.message.$markAsReadPromise)
           vm.service.$timeout.cancel(vm.message.$markAsReadPromise);
+        // Remove controller from window
+        delete $window.$messageController;
       });
 
     }; // $onInit
@@ -479,6 +481,12 @@
       }
     };
 
+    this.compose = function($event) {
+      if (!this._showMailEditorInPopup('compose')) {
+        _showMailEditor($event, this.message.$compose());
+      }
+    };
+
     this.openInPopup = function(action) {
       var url = [sgSettings.baseURL(),
                  'UIxMailPopupView#!/Mail',
