@@ -278,6 +278,18 @@
         this.showRecurrenceEditor = true;
     };
 
+    this.destinationCalendars = function () {
+      if (this.component.isNew)
+        // New component, return all writable calendars
+        return Calendar.$findAll(null, true);
+      else if (this.component.isErasable)
+        // Movable component, return all writable calendars including current one
+        return Calendar.$findAll(null, true, this.component.pid);
+      else
+        // Component can't be moved
+        return [Calendar.$get(this.component.pid)];
+    };
+
     this.changeCalendar = function () {
       var updateRequired = (this.component.attendees && this.component.attendees.length > 0);
       if (updateRequired)
@@ -294,12 +306,11 @@
           destinationCalendar = Calendar.$get(this.component.destinationCalendar),
           options = initOrganizer? { organizerCalendar: destinationCalendar } : {},
           promises = [];
-      var emailRE = /([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)/i,
-          i, address;
+      var i, address;
       if (partial) options.partial = partial;
 
       function createCard(str) {
-        var match = str.match(emailRE),
+        var match = str.match(String.emailRE),
             email = match[0],
             name = str.replace(new RegExp(" *<?" + email + ">? *"), '');
         vm.showAttendeesEditor |= initOrganizer;
@@ -333,7 +344,7 @@
                card.charCodeAt(i) == 32 ||   // space
                card.charCodeAt(i) == 44 ||   // ,
                card.charCodeAt(i) == 59) &&  // ;
-              emailRE.test(address)) {
+              String.emailRE.test(address)) {
             promises.push(createCard(address).then(addCard));
             address = '';
           }
@@ -341,7 +352,7 @@
             address += card.charAt(i);
           }
         }
-        if (address && emailRE.test(address)) {
+        if (address && String.emailRE.test(address)) {
           promises.push(createCard(address).then(addCard));
         }
       }
